<?php
namespace MascotCoreCooltech\Widgets\FeatureBlock\Skins;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Skin_Base as Elementor_Skin_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Skin_Style5 extends Elementor_Skin_Base {

	protected function _register_controls_actions() {
		add_action( 'elementor/element/tm-ele-block-features/general/after_section_end', [ $this, 'register_layout_controls' ] );
	}

	public function get_id() {
		return 'skin-style5';
	}


	public function get_title() {
		return __( 'Skin Style5', 'mascot-core-cooltech' );
	}


	public function register_layout_controls( Widget_Base $widget ) {
		$this->parent = $widget;

		//Current Background Styling
		$this->start_controls_section(
			'current_background_styling',
			[
				'label' => esc_html__( 'Current Background Styling', 'mascot-core-cooltech' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'content_wrapper_custom_bg_color',
			[
				'label' => esc_html__( "Custom Background Color", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content::after' => 'border-top-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_custom_bg_color_hover',
			[
				'label' => esc_html__( "Custom Background Color (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content::after' => 'border-top-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_icon_theme_colored',
			[
				'label' => esc_html__( "Make BG Theme Colored", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content' => 'background-color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content::after' => 'border-top-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_responsive_control(
			'content_wrapper_theme_colored_hover',
			[
				'label' => esc_html__( "Make BG Theme Colored (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content' => 'background-color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content::after' => 'border-top-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_section();



		//Current Title Styling
		$this->start_controls_section(
			'current_title_styling',
			[
				'label' => esc_html__( 'Current Title Styling', 'mascot-core-cooltech' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'title_wrapper_custom_color',
			[
				'label' => esc_html__( "Custom Title Color", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-title' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'title_wrapper_custom_color_hover',
			[
				'label' => esc_html__( "Custom Title Color (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-title' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'title_wrapper_theme_colored',
			[
				'label' => esc_html__( "Make Title Theme Colored", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-title' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_responsive_control(
			'title_wrapper_theme_colored_hover',
			[
				'label' => esc_html__( "Make Title Theme Colored (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-title' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_section();


		//Current Text Styling
		$this->start_controls_section(
			'current_text_styling',
			[
				'label' => esc_html__( 'Current Text Styling', 'mascot-core-cooltech' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'text_wrapper_custom_color',
			[
				'label' => esc_html__( "Custom Text Color", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-details' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'text_wrapper_custom_color_hover',
			[
				'label' => esc_html__( "Custom Text Color (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-details' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'text_wrapper_theme_colored',
			[
				'label' => esc_html__( "Make Text Theme Colored", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-details' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_responsive_control(
			'text_wrapper_theme_colored_hover',
			[
				'label' => esc_html__( "Make Text Theme Colored (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-details' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_section();


		//Icon Current Styling
		$this->start_controls_section(
			'current_icon_styling',
			[
				'label' => esc_html__( 'Current Icon Styling', 'mascot-core-cooltech' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_color',
			[
				'label' => esc_html__( "Custom Icon Color", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-icon .icon i::before' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_color_hover',
			[
				'label' => esc_html__( "Custom Icon Color (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-icon .icon i::before' => 'color: {{VALUE}};',
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_theme_colored',
			[
				'label' => esc_html__( "Make icon Theme Colored", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-icon .icon i::before' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_icon_theme_colored_hover',
			[
				'label' => esc_html__( "Make Icon Theme Colored (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-icon .icon i::before' => 'color: var(--theme-color{{VALUE}});',
				],
			]
		);



		//icon Background Styling
		$this->add_responsive_control(
			'content_wrapper_current_bg_color',
			[
				'label' => esc_html__( "Custom Background Color", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-icon .icon' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-icon .icon::after' => 'border-top-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_bg_color_hover',
			[
				'label' => esc_html__( "Custom Background Color (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-icon .icon' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-icon .icon::after' => 'border-top-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_colored',
			[
				'label' => esc_html__( "Make BG Theme Colored", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-icon .icon' => 'background-color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .feature-current-item-style5 .feature-inner .feature-content .feature-icon .icon::after' => 'border-top-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_responsive_control(
			'content_wrapper_current_theme_colored_hover',
			[
				'label' => esc_html__( "Make BG Theme Colored (Hover)", 'mascot-core-cooltech' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-icon .icon' => 'background-color: var(--theme-color{{VALUE}});',
					'{{WRAPPER}} .feature-current-item-style5:hover .feature-inner .feature-content .feature-icon .icon::after' => 'border-top-color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_section();
		
	}
	
	public function render() {
		$settings = $this->parent->get_settings_for_display();

		//link url
		$settings['target'] = ( $settings['link'] && $settings['link']['is_external'] ) ? ' target="_blank"' : '';
		$settings['url'] = ( $settings['link'] && $settings['link']['url'] ) ? $settings['link']['url'] : '';



		//classes
		$classes = array();
		$classes[] = $settings['custom_css_class'];

		if( $settings['animate_icon_on_hover'] ) {
			$classes[] = 'animate-icon-on-hover animate-icon-'.$settings['animate_icon_on_hover'];
		}

		$settings['classes'] = $classes;


		//icon classes
		$icon_classes = array();
		$settings['icon_classes'] = $icon_classes;

		//button classes
		$settings['btn_classes'] = mascot_core_prepare_button_classes_from_params( $settings );

		//title classes
		$title_classes = array();
		$settings['title_classes'] = $title_classes;

		//subtitle classes
		$subtitle_classes = array();
		$settings['subtitle_classes'] = $subtitle_classes;

		//icon classes
		$icon_classes = array();
		$settings['icon_classes'] = $icon_classes;

		$settings['settings'] = $settings;

		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
		$html = mascot_core_cooltech_get_shortcode_template_part( 'block-features-' . $settings['_skin'], null, 'block-features/tpl', $settings, true );

		echo $html;
	}
}